Resources
=========

Those parameters should be presented in the every request otherwise default values will be used.

.. toctree::
   :maxdepth: 2
   :titlesonly:
   
   Content
   Language
   Contact
